# Parboil - Project Boilerplate Generator

![GitHub](https://img.shields.io/github/license/jneug/parboil)

_Parboil_ lets you generate boilerplate projects from template files.

_Parboil_ is a Python rewrite of [boilr](https://github.com/tmrts/boilr) by [Tamer Tas](https://github.com/tmrts)
